
var fileController = {
  app : null,
  
  init : function(aApp) {
    this.app = aApp;
  },
  
  supportsCommand : function(cmd) {
    var isSupported = false;
    switch (cmd) {
      case "cmd_new_blank": 
      case "cmd_open": 
      case "cmd_save":
      case "cmd_pageSetup":
      case "cmd_print":
      case "cmd_exit":
        isSupported = true;
        break;
      default:
        isSupported = false;
        break;
    }
    return isSupported;
  },
  
  isCommandEnabled : function(cmd) {
    return true;
  },
  
  doCommand : function(cmd) {
    switch (cmd) {
      case "cmd_new_blank": 
      {
        this.app.clearSource();
        this.app.refreshPreview();
        break;
      }
      case "cmd_open":
      {
        /* See: http://developer.mozilla.org/en/docs/XUL_Tutorial:Open_and_Save_Dialogs */
        
        var nsIFilePicker = Components.interfaces.nsIFilePicker;
        var fp = Components.classes["@mozilla.org/filepicker;1"].createInstance(nsIFilePicker);
      
        fp.init(window, "Open File", nsIFilePicker.modeOpen);
        fp.appendFilters(nsIFilePicker.filterText | nsIFilePicker.filterAll);
        
        var res = fp.show();
        if (res == nsIFilePicker.returnOK) {
          var source = fileToString(fp.file);
          this.app.setSource(source);
        }
        
        break;
      }
      case "cmd_save":
      {
        /* See: http://developer.mozilla.org/en/docs/XUL_Tutorial:Open_and_Save_Dialogs */
        
        var nsIFilePicker = Components.interfaces.nsIFilePicker;
        var fp = Components.classes["@mozilla.org/filepicker;1"].createInstance(nsIFilePicker);
      
        fp.init(window, "Save File", nsIFilePicker.modeSave);
        fp.appendFilters(nsIFilePicker.filterText | nsIFilePicker.filterAll);
        
        var res = fp.show();
        if (res == nsIFilePicker.returnOK | res == nsIFilePicker.returnReplace) {
          var source = this.app.getSource();
          stringToFile(source, fp.file);
        }
        
        break;
      }
      case "cmd_pageSetup":
      {
        PrintUtils.showPageSetup();
        break;
      }
      case "cmd_print":
      {
        PrintUtils.print();
        break;
      }
      case "cmd_exit":
      {
        var aForceQuit = false;
        var appStartup = Components.classes['@mozilla.org/toolkit/app-startup;1'].getService(Components.interfaces.nsIAppStartup);
      
        // eAttemptQuit will try to close each XUL window, but the XUL window can cancel the quit
        // process if there is unsaved data. eForceQuit will quit no matter what.
        var quitSeverity = aForceQuit ? Components.interfaces.nsIAppStartup.eForceQuit : Components.interfaces.nsIAppStartup.eAttemptQuit;
        appStartup.quit(quitSeverity);

        break;
      }
    }
  }
};


var viewController = {
  app : null,
  
  init : function(aApp) {
    this.app = aApp;
  },
  
  supportsCommand : function(cmd) {
    var isSupported = false;
    switch (cmd) {
      case "cmd_refresh": 
      case "cmd_preview": 
        isSupported = true;
        break;
      default:
        isSupported = false;
        break;
    }
    return isSupported;
  },
  
  isCommandEnabled : function(cmd) {
    return true;
  },
  
  doCommand : function(cmd) {
    switch (cmd) {
      case "cmd_refresh": 
      {
        this.refresh();
        break;
      }
      case "cmd_preview": 
      {
        this.app.openPreview();
        window.setTimeout(this.refresh, 100);
        break;
      }
    }
  },
  
  refresh : function() {
    this.app.refreshPreview();
  }
};


var toolsController = {
  app : null,
  
  init : function(aApp) {
    this.app = aApp;
  },
  
  supportsCommand : function(cmd) {
    var isSupported = false;
    switch (cmd) {
      case "cmd_checker": 
      case "cmd_console": 
      case "cmd_options": 
        isSupported = true;
        break;
      default:
        isSupported = false;
        break;
    }
    return isSupported;
  },
  
  isCommandEnabled : function(cmd) {
    return true;
  },
  
  doCommand : function(cmd) {
    switch (cmd) {
      case "cmd_checker": 
      {
        var source = this.app.getSource();
        XULChecker.checkString(source);
        break;
      }
      case "cmd_console": 
      {
        window.open("chrome://global/content/console.xul", "_blank", "chrome,extrachrome,dependent,menubar,resizable,scrollbars,status,toolbar");
        break;
      }
      case "cmd_options": 
      {
        window.openDialog("chrome://explorer/content/options.xul", "options", "chrome,titlebar,toolbar,centerscreen,modal");
        break;
      }
    }
  }
};


var helpController = {
  app : null,
  
  init : function(aApp) {
    this.app = aApp;
  },
  
  supportsCommand : function(cmd) {
    var isSupported = false;
    switch (cmd) {
      case "cmd_help": 
      case "cmd_xulref": 
      case "cmd_xultut": 
      case "cmd_jsref": 
      case "cmd_keyword": 
      case "cmd_about": 
        isSupported = true;
        break;
      default:
        isSupported = false;
        break;
    }
    return isSupported;
  },
  
  isCommandEnabled : function(cmd) {
    return true;
  },
  
  doCommand : function(cmd) {
    switch (cmd) {
      case "cmd_help": 
      case "cmd_xulref": 
      case "cmd_xultut": 
      case "cmd_keyword": 
      case "cmd_jsref": 
      {
        var helpURI = this.app.getHelpURI(cmd);
        window.openDialog("chrome://explorer/content/helpbrowser.xul", "_blank", "chrome,dependent,resizable,scrollbars", helpURI);
        break;
      }
      case "cmd_about": 
      {
        window.openDialog("chrome://explorer/content/about.xul", "about", "centerscreen,modal");
        break;
      }
    }
  }
};

